#
# spec file for package python-dns-lexicon
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-dns-lexicon
Version:        2.2.1
Release:        2.19
Summary:        DNS record manipulation utility
License:        MIT
Group:          Productivity/Networking/DNS/Utilities
URL:            https://github.com/AnalogJ/lexicon
Source0:        https://github.com/AnalogJ/lexicon/archive/v%{version}.tar.gz
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module softlayer}
BuildRequires:  %{python_module tldextract}
BuildRequires:  %{python_module transip >= 0.3.0}
BuildRequires:  %{python_module vcrpy}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-boto3
Requires:       python-future
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-softlayer
Requires:       python-tldextract
Requires:       python-transip >= 0.3.0
Requires:       python-vcrpy
# Completely different pkg but same namespace
Conflicts:      python-lexicon
BuildArch:      noarch
%python_subpackages

%description
Lexicon provides a way to manipulate DNS records on multiple DNS providers
in a standardized way. Lexicon has a CLI, but it can also be used as a
Python library.

Lexicon was designed to be used in automation, specifically letsencrypt.

%prep
%setup -q -n lexicon-%{version}
# remove namecheap tests/require as we don't have all the support libs
rm -f tests/providers/test_namecheap.py

# rpmlint
find . -type f -name ".gitignore" -delete

%build
%python_build

# rpmlint
find . -type f -name ".buildinfo" -delete

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
# Python2 incompatible, only py3 syntax in tests
python3 -m pytest tests

%files %{python_files}
%{python_sitelib}/lexicon
%{python_sitelib}/dns_lexicon-*
%license LICENSE
%doc README.md
%python3_only %{_bindir}/lexicon

%changelog
* Mon Apr 23 2018 tchvatal@suse.com
- Conflict with python-lexicon that uses same namespace in sitedir
* Mon Apr 16 2018 jengelh@inai.de
- Use POSIX-compliant syntax of find (requires a directory).
  Use -delete in the same go.
- Update descriptions.
* Sun Apr 15 2018 tchvatal@suse.com
- Expand dependencies in order to run tests
* Sat Apr 14 2018 ecsos@opensuse.org
- Update to version 2.2.1
  No changelog from upstream.
* Wed Dec 13 2017 archie.cobbs@gmail.com
- Update to version 2.1.16
* Sun Jul 31 2016 archie.cobbs@gmail.com
- Update to version 1.1.9
  + Add support for setting TTL, with default 60 minutes
  + Add Gandi support
  + Added luadns support
  + Added fdqn method
  + Added certbot plugin
- Add missing requirement for python-setuptools
* Sun Jun 19 2016 archie.cobbs@gmail.com
- Initial creation of package, version 1.1.6
